==> apache-ignite-2.9.1-src.zip: apache-ignite-2.9.1-src/modules/core/src/main/java/org/apache/ignite/internal/visor/misc/VisorIdAndTagViewTaskResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.visor.misc;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.util.UUID;
import org.apache.ignite.internal.dto.IgniteDataTransferObject;

/**
 *
 */
public class VisorIdAndTagViewTaskResult extends IgniteDataTransferObject {
    /** */
    private static final long serialVersionUID = 0L;

    /** */
    private UUID id;

    /** */
    private String tag;

    /** Default constructor. */
    public VisorIdAndTagViewTaskResult() {
        // No-op.
    }

    /**
     * @param id Cluster ID.
     * @param tag Cluster tag.
     */
    public VisorIdAndTagViewTaskResult(UUID id, String tag) {
        this.id = id;
        this.tag = tag;
    }

    /** {@inheritDoc} */
    @Override protected void writeExternalData(ObjectOutput out) throws IOException {
        out.writeObject(id);
        out.writeObject(tag);
    }

    /** {@inheritDoc} */
    @Override protected void readExternalData(byte protoVer, ObjectInput in) throws IOException, ClassNotFoundException {
        id = (UUID)in.readObject();
        tag = (String)in.readObject();
    }

    /** */
    public UUID id() {
        return id;
    }

    /** */
    public String tag() {
        return tag;
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/core/src/main/java/org/apache/ignite/internal/visor/misc/VisorIdAndTagViewTaskResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.visor.misc;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.util.UUID;
import org.apache.ignite.internal.dto.IgniteDataTransferObject;

/**
 *
 */
public class VisorIdAndTagViewTaskResult extends IgniteDataTransferObject {
    /** */
    private static final long serialVersionUID = 0L;

    /** */
    private UUID id;

    /** */
    private String tag;

    /** */
    private String clusterName;

    /** Default constructor. */
    public VisorIdAndTagViewTaskResult() {
        // No-op.
    }

    /**
     * @param id Cluster ID.
     * @param tag Cluster tag.
     * @param clusterName Cluster name.
     */
    public VisorIdAndTagViewTaskResult(UUID id, String tag, String clusterName) {
        this.id = id;
        this.tag = tag;
        this.clusterName = clusterName;
    }

    /** {@inheritDoc} */
    @Override protected void writeExternalData(ObjectOutput out) throws IOException {
        out.writeObject(id);
        out.writeObject(tag);
        out.writeObject(clusterName);
    }

    /** {@inheritDoc} */
    @Override protected void readExternalData(byte protoVer, ObjectInput in) throws IOException, ClassNotFoundException {
        id = (UUID)in.readObject();
        tag = (String)in.readObject();
        clusterName = (String)in.readObject();
    }

    /** */
    public UUID id() {
        return id;
    }

    /** */
    public String tag() {
        return tag;
    }

    /** */
    public String clusterName() {
        return clusterName;
    }
}
